#include <iostream>
#include <iomanip>
#include <algorithm>
#include <cmath>
#include <vector>

using namespace std;

const double eps = 1.0e-6;

struct Point {
    double x, y;
};

struct Ray {
    Point p1, p2;
};

struct Vector {
    Point p1, p2;
};

struct Segment {
    Point p1, p2;
};

struct Line {
    Point p1, p2;
};

struct RichLine {
    double a, b, c;

    explicit RichLine(Line L) {
        a = L.p2.y - L.p1.y;
        b = L.p1.x - L.p2.x;
        c = -a * L.p1.x - b * L.p1.y;
    }
};

Point linesIntersect(Line line1, Line line2) {
    RichLine L1(line1);
    RichLine L2(line2);
    double x = (L2.c * L1.b - L1.c * L2.b) / (L1.a * L2.b - L2.a * L1.b);
    double y = (L2.c * L1.a - L1.c * L2.a) / (L1.b * L2.a - L2.b * L1.a);
    return Point{x, y};
}

double sqr(double x) {
    return x * x;
}

double distPointToPoint(Point p1, Point p2) {
    return sqrt(sqr(p1.x - p2.x) + sqr(p1.y - p2.y));
}

double getX(Vector v) {
    return v.p2.x - v.p1.x;
}

double getY(Vector v) {
    return v.p2.y - v.p1.y;
}

double length(Vector v) {
    return distPointToPoint(v.p1, v.p2);
}

double length(Segment v) {
    return distPointToPoint(v.p1, v.p2);
}

double scalarProd(Vector v1, Vector v2) {
    return getX(v1) * getX(v2) + getY(v1) * getY(v2);
}

double pseudoProd(Vector v1, Vector v2) {
    return getX(v1) * getY(v2) - getY(v1) * getX(v2);
}

double distPointToLine(Point p, Line L) {
    Vector v1{L.p1, L.p2};
    Vector v2{L.p1, p};
    return abs(pseudoProd(v1, v2) / length(v1));
}

double distPointToRay(Point p, Ray ray) {
    Vector v1{ray.p1, ray.p2};
    Vector v2{ray.p1, p};
    // prod >= 0
    if (scalarProd(v1, v2) > -eps) {
        // the perpendicular hits the ray
        Line L{ray.p1, ray.p2};
        return distPointToLine(p, L);
    }
    return distPointToPoint(p, ray.p1);
}

double distPointToSegment(Point p, Segment seg) {
    Vector v1{seg.p1, seg.p2};
    Vector v2{seg.p1, p};
    Vector v3{seg.p2, seg.p1};
    Vector v4{seg.p2, p};
    // prod >= 0
    if (scalarProd(v1, v2) > -eps && scalarProd(v3, v4) > -eps) {
        // the perpendicular hits the segment
        Line L{seg.p1, seg.p2};
        return distPointToLine(p, L);
    }
    return min(distPointToPoint(p, seg.p1), distPointToPoint(p, seg.p2));
}

bool checkPointsOnDifferentSides(Segment seg, Point p1, Point p2) {
    Vector v1{seg.p1, seg.p2};
    Vector v2{seg.p1, p1};
    Vector v3{seg.p1, p2};
    // prod < 0
    return (pseudoProd(v1, v2) * pseudoProd(v1, v3) < -eps);
}

bool checkPointOnLine(Point p, Line L) {
    Vector v1{L.p1, L.p2};
    Vector v2{L.p1, p};
    return (abs(pseudoProd(v1, v2)) < eps);
}

bool checkPointOnRay(Point p, Ray ray) {
    Vector v1{ray.p1, ray.p2};
    Vector v2{ray.p1, p};
    return (abs(pseudoProd(v1, v2)) < eps && scalarProd(v1, v2) > -eps);
}

bool checkPointOnSegment(Point p, Segment seg) {
    Vector v1{seg.p1, seg.p2};
    Vector v2{seg.p1, p};
    Vector v3{p, seg.p1};
    Vector v4{p, seg.p2};
    return (abs(pseudoProd(v1, v2)) < eps && scalarProd(v3, v4) < eps);
}

bool checkLinesIntersect(Line line1, Line line2) {
    Vector v1{line1.p1, line1.p2};
    Vector v2{line2.p1, line2.p2};
    return abs(pseudoProd(v1, v2)) > eps;
}

bool checkRaysIntersect(Ray first, Ray second) {
    Line L1{first.p1, first.p2};
    if (checkPointOnLine(second.p1, L1) && checkPointOnLine(second.p2, L1)) {
        bool f1 = checkPointOnRay(first.p1, second);
        bool f2 = checkPointOnRay(second.p1, first);
        return f1 || f2;
    }
    Line L2{second.p1, second.p2};
    Point P = linesIntersect(L1, L2);
    return checkPointOnRay(P, first) && checkPointOnRay(P, second);
}

bool checkSegmentsIntersect(Segment seg1, Segment seg2) {
    if (checkPointsOnDifferentSides(seg1, seg2.p1, seg2.p2) &&
        checkPointsOnDifferentSides(seg2, seg1.p1, seg1.p2)) {
        return true;
    }
    if (checkPointOnSegment(seg1.p1, seg2) ||
        checkPointOnSegment(seg1.p2, seg2) ||
        checkPointOnSegment(seg2.p1, seg1) ||
        checkPointOnSegment(seg2.p2, seg1)) {
        return true;
    }
    return false;
}

bool checkSegmentLineIntersect(Segment seg, Line line) {
    Segment seg2{line.p1, line.p2};
    return checkPointsOnDifferentSides(seg2, seg.p1, seg.p2);
}

bool checkSegmentRayIntersect(Segment seg, Ray ray) {
    Ray r1{seg.p1, seg.p2};
    if (!checkRaysIntersect(r1, ray))
        return false;
    Ray r2{seg.p2, seg.p1};
    return checkRaysIntersect(r2, ray);
}

double distLineToLine(Line line1, Line line2) {
    if (checkLinesIntersect(line1, line2))
        return 0.0;
    return distPointToLine(line1.p1, line2);
}

double distRayToRay(Ray first, Ray second) {
    if (checkRaysIntersect(first, second))
        return 0.0;
    double d1 = distPointToRay(first.p1, second);
    double d2 = distPointToRay(second.p1, first);
    return min(d1, d2);
}

double distSegmentToSegment(Segment first, Segment second) {
    if (checkSegmentsIntersect(first, second))
        return 0.0;
    double dist1 = distPointToSegment(first.p1, second);
    double dist2 = distPointToSegment(first.p2, second);
    double dist3 = distPointToSegment(second.p1, first);
    double dist4 = distPointToSegment(second.p2, first);
    return min(min(dist1, dist2), min(dist3, dist4));
}

double distRayToLine(Ray ray, Line line) {
    double d1 = distPointToLine(ray.p1, line);
    Line L{ray.p1, ray.p2};
    if (checkLinesIntersect(L, line)) {
        Point P = linesIntersect(L, line);
        double d2 = distPointToRay(P, ray);
        return min(d1, d2);
    }
    return d1;
}

double distSegmentToLine(Segment seg, Line line) {
    if (checkSegmentLineIntersect(seg, line))
        return 0.0;
    double d1 = distPointToLine(seg.p1, line);
    double d2 = distPointToLine(seg.p2, line);
    return min(d1, d2);
}

double distSegmentToRay(Segment seg, Ray ray) {
    if (checkSegmentRayIntersect(seg, ray))
        return 0.0;
    double d1 = distPointToRay(seg.p1, ray);
    double d2 = distPointToRay(seg.p2, ray);
    double d3 = distPointToSegment(ray.p1, seg);
    return min(d1, min(d2, d3));
}

void print(double x) {
    cout << setprecision(10) << x << '\n';
}

bool mainCheck(Segment A, Segment B, Segment C) {
//    cout << distSegmentToSegment(A, B) << " " << length(C) << "\n";
//    cout << distSegmentToSegment(A, C) << " " << length(B) << "\n";
//    cout << distSegmentToSegment(B, C) << " " << length(A) << "\n";
    if (distSegmentToSegment(A, B) < length(C) + eps) {
        return true;
    }
    if (distSegmentToSegment(A, C) < length(B) + eps) {
        return true;
    }
    if (distSegmentToSegment(B, C) < length(A) + eps) {
        return true;
    }
    return false;
}

int main() {
    int m;
    cin >> m;

    vector<Segment> segments;

    for (int i = 0; i < m; i++) {
        int x1, y1, x2, y2;
        cin >> x1 >> y1 >> x2 >> y2;

        auto A1 = Point{(double) x1, (double) y1};
        auto A2 = Point{(double) x2, (double) y2};

        segments.push_back(Segment{A1, A2});
    }

    long long cnt = 0;

    for (int i = 0; i < segments.size(); i++) {
        for (int j = i + 1; j < segments.size(); j++) {
            for (int k = j + 1; k < segments.size(); k++) {
                if (mainCheck(segments[i], segments[j], segments[k])) cnt++;
            }
        }
    }

    cout << cnt;

    return 0;
}
